@@ -1,7 +1,7 @@
 /*****************************************************************************
  * mp2v.h: ISO/IEC 13818-2 (video)
  *****************************************************************************
- * Copyright (C) 2013 VideoLAN
+ * Copyright (C) 2013-2015 VideoLAN
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -28,6 +28,7 @@
 /*
  * Normative references:
  *  - ISO/IEC 13818-2 (MPEG-2 video)
+ *  - ISO/IEC JTC1/SC29/WG11 MPEG2007/m14868 (high progressive profile)
  */
 
 #ifndef __BITSTREAM_MPEG_MP2V_H__
@@ -283,11 +284,18 @@ static inline bool mp2vseq_get_nonintramatrix(const uint8_t *p_mp2vseq,
 #define MP2VSEQX_PROFILE_SNR_SCAL   (3 << 4)
 #define MP2VSEQX_PROFILE_SPAT_SCAL  (2 << 4)
 #define MP2VSEQX_PROFILE_HIGH       (1 << 4)
-#define MP2VSEQX_LEVEL_MASK         0xf
+#define MP2VSEQX_LEVEL_MASK         0x8f /* with escape bit */
 #define MP2VSEQX_LEVEL_LOW          10
 #define MP2VSEQX_LEVEL_MAIN         8
 #define MP2VSEQX_LEVEL_HIGH1440     6
 #define MP2VSEQX_LEVEL_HIGH         4
+#define MP2VSEQX_LEVEL_HIGHP        2
+#define MPV2SEQX_LEVEL_LOW_MV       0x8e
+#define MPV2SEQX_LEVEL_MAIN_MV      0x8d
+#define MPV2SEQX_LEVEL_HIGH_MV      0x8b
+#define MPV2SEQX_LEVEL_HIGH1440_MV  0x8a
+#define MPV2SEQX_LEVEL_MAIN_422     0x85
+#define MPV2SEQX_LEVEL_HIGH_422     0x82
 
 #define MP2VSEQX_CHROMA_420         1
 #define MP2VSEQX_CHROMA_422         2
